package Bundle::CpanTestDummies;

$VERSION = '1.55';

1;

__END__

=head1 NAME

Bundle::CpanTestDummies - A bundle only for testing CPAN.pm

=head1 SYNOPSIS

  --- No Synopsis ---

=head1 CONTENTS

CPAN::Test::Dummy::Perl5::Build
CPAN::Test::Dummy::Perl5::Build::Fails
CPAN::Test::Dummy::Perl5::Make

=head1 DESCRIPTION

Within the CPAN.pm t/ directory, we keep this bundle like a private
bundle of the user we emulate.

=head1 AUTHOR

Andreas Koenig
